%define modname pywt
%define pkgname PyWavelets

Name:           python-%{modname}
Version:        0.5.2
Release:        2%{?dist}
Summary:        PyWavelets, wavelet transform module
License:        MIT
URL:            http://pywavelets.readthedocs.org/
Source0:        https://github.com/PyWavelets/pywt/archive/v%{version}/%{pkgname}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires: xorg-x11-server-Xvfb

%description
PyWavelets is a Python wavelet transforms module that can do:

* 1D and 2D Forward and Inverse Discrete Wavelet Transform (DWT and IDWT)
* 1D and 2D Stationary Wavelet Transform (Undecimated Wavelet Transform)
* 1D and 2D Wavelet Packet decomposition and reconstruction
* Computing Approximations of wavelet and scaling functions
* Over seventy built-in wavelet filters and support for custom wavelets
* Single and double precision calculations
* Results compatibility with Matlab Wavelet Toolbox

%package doc
Summary:        Documentation for %{name}

%description doc
Documentation for %{name}

%package -n python2-%{modname}
Summary:        %{summary}
%{?python_provide:%python_provide python2-%{modname}}
BuildRequires:  python2-devel Cython
BuildRequires:  numpy
BuildRequires:  python2-nose
BuildRequires:  python-sphinx
BuildRequires:  python-numpydoc
Requires:       numpy

%description -n python2-%{modname}
PyWavelets is a Python wavelet transforms module that can do:

* 1D and 2D Forward and Inverse Discrete Wavelet Transform (DWT and IDWT)
* 1D and 2D Stationary Wavelet Transform (Undecimated Wavelet Transform)
* 1D and 2D Wavelet Packet decomposition and reconstruction
* Computing Approximations of wavelet and scaling functions
* Over seventy built-in wavelet filters and support for custom wavelets
* Single and double precision calculations
* Results compatibility with Matlab Wavelet Toolbox

Python 2 version.

%package -n python3-%{modname}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{modname}}
BuildRequires:  python3-devel python3-Cython
BuildRequires:  python3-numpy
BuildRequires:  python3-nose
BuildRequires:  python3-sphinx
BuildRequires:  python3-numpydoc
Requires:       python3-numpy

%description -n python3-%{modname}
PyWavelets is a Python wavelet transforms module that can do:

* 1D and 2D Forward and Inverse Discrete Wavelet Transform (DWT and IDWT)
* 1D and 2D Stationary Wavelet Transform (Undecimated Wavelet Transform)
* 1D and 2D Wavelet Packet decomposition and reconstruction
* Computing Approximations of wavelet and scaling functions
* Over seventy built-in wavelet filters and support for custom wavelets
* Single and double precision calculations
* Results compatibility with Matlab Wavelet Toolbox

Python 3 version.

%prep
%autosetup -n %{modname}-%{version}

sed -i '1{\@^#!/usr/bin/env python@d}' %{modname}/tests/*.py 

%build
%py2_build
%py3_build

pushd doc
  export PYTHONPATH=`readlink -f ../build/lib.*-%{python3_version}`
  make html SPHINXBUILD=sphinx-build-%{python3_version}
  find -name '.buildinfo' -delete
popd

%install
%py2_install
%py3_install

%check
# Ignoring error in some arches
# https://github.com/PyWavelets/pywt/issues/316
mkdir -p matplotlib
touch matplotlib/matplotlibrc
export XDG_CONFIG_HOME=`pwd`
pushd %{buildroot}/%{python2_sitearch}
%ifarch ppc64le aarch64 ppc64 s390x
  xvfb-run nosetests-%{python2_version} pywt -verbose --no-byte-compile || :
%else
  xvfb-run nosetests-%{python2_version} pywt -verbose --no-byte-compile
%endif
popd
pushd %{buildroot}/%{python3_sitearch}
%ifarch ppc64le aarch64 ppc64 s390x
  xvfb-run nosetests-%{python3_version} pywt -verbose --no-byte-compile || :
%else
  xvfb-run nosetests-%{python3_version} pywt -verbose --no-byte-compile
%endif
popd

%files doc
%doc doc/build/html

%files -n python2-%{modname}
%license COPYING
%doc README.rst THANKS.txt
%{python2_sitearch}/%{modname}/
%{python2_sitearch}/%{pkgname}*.egg-info

%files -n python3-%{modname}
%license COPYING
%doc README.rst THANKS.txt
%{python3_sitearch}/%{modname}/
%{python3_sitearch}/%{pkgname}*.egg-info

%changelog
* Wed May 31 2017 Sergio Pascual  <sergiopr@fedoraproject.org> - 0.5.2-2
- Skip tolerance error en tests (for ppc64le aarch64 ppc64 s390x)

* Wed May 31 2017 Sergio Pascual  <sergiopr@fedoraproject.org> - 0.5.2-1
- New upstream source (0.5.2)
- Run tests with matplotlib under xvfb-run

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.3.0-5
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Nov 28 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3.0-2
- One doc subpkg
- Drop shebangs from tests

* Fri Nov 06 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3.0-1
- Initial package
